import {
  CacheType,
  ChatInputCommandInteraction,
  Interaction,
} from "discord.js";
import config from "config";
import EventEmitter from "events";
import DiscordService from "Services/discord.service";

export default class DiscordController extends EventEmitter {
  private discordService!: DiscordService;

  constructor() {
    super();
    this.discordService = new DiscordService();
    this.discordService.client.once("ready", () => {
      console.log("Listening...");
    });
    this.discordService.client.on(
      "interactionCreate",
      this.handleInteraction.bind(this)
    );
  }

  async init() {
    await this.discordService.init();
  }

  async handleInteraction(interaction: Interaction<CacheType>) {
    if (!interaction.isChatInputCommand()) return;

    const { commandName } = interaction;

    switch (commandName) {
      case "quote":
        await this.quote(interaction);
      default:
        break;
    }
  }

  async quote(interaction: ChatInputCommandInteraction<CacheType>) {
    // find the channel with configured id
    const channel = this.discordService.client.channels.cache.find(
      (ch) => ch.id === config.discord.channelId
    );

    if (channel?.isTextBased()) {
      // send quote content as message
      channel.send(interaction.options.getString("content") || "");

      interaction.reply({
        content: "Completed! (only you see this)",
        ephemeral: true,
      });
      return;
    }
  }
}
